@@ -3,6 +3,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
+#include <QCoreApplication>
 #include <QFile>
 #include <QFileInfo>
 #include <QJsonDocument>
@@ -12,7 +13,9 @@
 int main(int argc, char **argv)
 {
     Q_ASSERT(argc == 3);
-    QString fileName = QString::fromLatin1(argv[1]);
+    // Use QCoreApplication to parse arguments to handle encoding correctly
+    QCoreApplication app(argc, argv);
+    QString fileName = app.arguments().at(1);
 
     QFile file(fileName);
     bool isOpen = file.open(QIODevice::ReadOnly);
@@ -26,7 +29,7 @@ int main(int argc, char **argv)
     const QJsonObject kplugin = doc.object().value(QLatin1String("KPlugin")).toObject();
     const QLatin1String namePrefix("Name");
 
-    QFile out(QString::fromLatin1(argv[2]));
+    QFile out(app.arguments().at(2));
     out.open(QIODevice::WriteOnly);
     out.write("[Desktop Entry]\n");
     out.write("Type=Application\n");
@@ -39,15 +42,15 @@ int main(int argc, char **argv)
     }
 
     const QString exec = QLatin1String("Exec=") + executableProgram + QFileInfo(fileName).baseName() + QLatin1Char('\n');
-    out.write(exec.toLatin1());
+    out.write(exec.toUtf8());
     const QString icon = QLatin1String("Icon=") + kplugin.value(QLatin1String("Icon")).toString() + QLatin1Char('\n');
-    out.write(icon.toLatin1());
+    out.write(icon.toUtf8());
 
     for (auto it = kplugin.begin(), end = kplugin.end(); it != end; ++it) {
         const QString key = it.key();
         if (key.startsWith(namePrefix)) {
             const QString name = key + QLatin1Char('=') + it.value().toString() + QLatin1Char('\n');
-            out.write(name.toLocal8Bit());
+            out.write(name.toUtf8());
         }
     }
 }
